@@ -216,7 +216,7 @@ type ReportingOperatorPrometheusMetricsImporterConfigSpec struct {
 	StepSize                  *meta.Duration `json:"stepSize,omitempty"`
 	ImportFrom                *meta.Time     `json:"importFrom,omitempty"`
 	MaxImportBackfillDuration *meta.Duration `json:"maxImportBackfillDuration,omitempty"`
-	MaxQueryRangeDuration     string         `json:"maxQueryRangeDuration,omitempty"`
+	MaxQueryRangeDuration     *meta.Duration `json:"maxQueryRangeDuration,omitempty"`
 }
 type ReportingOperatorPrometheusConfigMapConfig struct {
 	Create   *bool  `json:"create,omitempty"`
@@ -442,8 +442,9 @@ type PrestoWorkerSpec struct {
 	Config                        *PrestoServerConfig          `json:"config,omitempty"`
 }
 type PrestoConnectorConfig struct {
-	Hive              *PrestoConnectorHiveConfig `json:"hive,omitempty"`
-	ConnectorFileList *PrestoConnectorFileList   `json:"extraConnectorFiles,omitempty"`
+	Hive              *PrestoConnectorHiveConfig       `json:"hive,omitempty"`
+	Prometheus        *PrestoConnectorPrometheusConfig `json:"prometheus,omitempty"`
+	ConnectorFileList *PrestoConnectorFileList         `json:"extraConnectorFiles,omitempty"`
 }
 type PrestoConnectorHiveConfig struct {
 	UseHadoopConfig        *bool      `json:"useHadoopConfig,omitempty"`
@@ -452,6 +453,9 @@ type PrestoConnectorHiveConfig struct {
 	MetastoreTimeout       string     `json:"metastoreTimeout,omitempty"`
 	TLS                    *TLSConfig `json:"tls,omitempty"`
 }
+type PrestoConnectorPrometheusConfig struct {
+	Enabled *bool `json:"enabled,omitempty"`
+}
 type PrestoConnectorFileList struct {
 	Name    string `json:"name,omitempty"`
 	Content string `json:"content,omitempty"`
@@ -470,7 +474,7 @@ End of Presto section
 */
 
 type Hive struct {
-	Spec HiveSpec `json:"spec,omitempty"`
+	Spec *HiveSpec `json:"spec,omitempty"`
 }
 type HiveSpec struct {
 	TerminationGracePeriodSeconds *int64                  `json:"terminationGracePeriodSeconds,omitempty"`
