@@ -38,20 +38,18 @@ import (
 	"k8s.io/client-go/transport"
 	"k8s.io/client-go/util/workqueue"
 
-	metering "github.com/operator-framework/operator-metering/pkg/apis/metering/v1"
-	"github.com/operator-framework/operator-metering/pkg/db"
-	cbClientset "github.com/operator-framework/operator-metering/pkg/generated/clientset/versioned"
-	factory "github.com/operator-framework/operator-metering/pkg/generated/informers/externalversions"
-	listers "github.com/operator-framework/operator-metering/pkg/generated/listers/metering/v1"
-	"github.com/operator-framework/operator-metering/pkg/operator/prestostore"
-	"github.com/operator-framework/operator-metering/pkg/operator/reporting"
-	_ "github.com/operator-framework/operator-metering/pkg/util/reflector/prometheus" // for prometheus metric registration
-	_ "github.com/operator-framework/operator-metering/pkg/util/workqueue/prometheus" // for prometheus metric registration
+	metering "github.com/kube-reporting/metering-operator/pkg/apis/metering/v1"
+	"github.com/kube-reporting/metering-operator/pkg/db"
+	cbClientset "github.com/kube-reporting/metering-operator/pkg/generated/clientset/versioned"
+	factory "github.com/kube-reporting/metering-operator/pkg/generated/informers/externalversions"
+	listers "github.com/kube-reporting/metering-operator/pkg/generated/listers/metering/v1"
+	"github.com/kube-reporting/metering-operator/pkg/operator/prestostore"
+	"github.com/kube-reporting/metering-operator/pkg/operator/reporting"
+	_ "github.com/kube-reporting/metering-operator/pkg/util/reflector/prometheus" // for prometheus metric registration
+	_ "github.com/kube-reporting/metering-operator/pkg/util/workqueue/prometheus" // for prometheus metric registration
 )
 
 const (
-	connBackoff         = time.Second * 15
-	maxConnRetries      = 3
 	defaultResyncPeriod = time.Minute * 15
 	prestoUsername      = "reporting-operator"
 
@@ -265,7 +263,6 @@ func newReportingOperator(
 	meteringClient cbClientset.Interface,
 	informerNamespace string,
 ) *Reporting {
-
 	informerFactory := factory.NewFilteredSharedInformerFactory(meteringClient, defaultResyncPeriod, informerNamespace, nil)
 
 	prestoTableInformer := informerFactory.Metering().V1().PrestoTables()
@@ -446,9 +443,6 @@ func (op *Reporting) Run(ctx context.Context) error {
 	}
 
 	hiveQueryer := sql.OpenDB(hiveDB)
-	if err != nil {
-		return err
-	}
 	hiveQueryer.SetConnMaxLifetime(time.Minute)
 	hiveQueryer.SetMaxOpenConns(2)
 	hiveQueryer.SetMaxIdleConns(2)
@@ -497,7 +491,10 @@ func (op *Reporting) Run(ctx context.Context) error {
 
 		prestoURL.Scheme = "https"
 		val.Set("custom_client", "httpClient")
-		presto.RegisterCustomClient("httpClient", httpClient)
+		err = presto.RegisterCustomClient("httpClient", httpClient)
+		if err != nil {
+			return fmt.Errorf("presto: Failed to register a custom HTTP client: %v", err)
+		}
 	}
 
 	prestoURL.RawQuery = val.Encode()
@@ -558,7 +555,7 @@ func (op *Reporting) Run(ctx context.Context) error {
 		defer wg.Done()
 		var srvErr error
 		if op.cfg.APITLSConfig.UseTLS {
-			op.logger.Infof("HTTP API server listening with TLS on 127.0.0.1:8080")
+			op.logger.Infof("HTTP API server listening with TLS on %s", op.cfg.APIListen)
 			srvErr = httpServer.ListenAndServeTLS(op.cfg.APITLSConfig.TLSCert, op.cfg.APITLSConfig.TLSKey)
 		} else {
 			op.logger.Infof("HTTP API server listening on %s", op.cfg.APIListen)
